@@ -61,16 +61,17 @@ func statusRun(opts *StatusOptions) error {
 	if err != nil {
 		return err
 	}
+	authCfg := cfg.Authentication()
 
 	// TODO check tty
 
 	stderr := opts.IO.ErrOut
-
+	stdout := opts.IO.Out
 	cs := opts.IO.ColorScheme()
 
 	statusInfo := map[string][]string{}
 
-	hostnames := cfg.Hosts()
+	hostnames := authCfg.Hosts()
 	if len(hostnames) == 0 {
 		fmt.Fprintf(stderr,
 			"You are not logged into any GitHub hosts. Run %s to authenticate.\n", cs.Bold("gh auth login"))
@@ -91,13 +92,13 @@ func statusRun(opts *StatusOptions) error {
 		}
 		isHostnameFound = true
 
-		token, tokenSource := cfg.AuthToken(hostname)
+		token, tokenSource := authCfg.Token(hostname)
 		if tokenSource == "oauth_token" {
 			// The go-gh function TokenForHost returns this value as source for tokens read from the
 			// config file, but we want the file path instead. This attempts to reconstruct it.
 			tokenSource = filepath.Join(config.ConfigDir(), "hosts.yml")
 		}
-		_, tokenIsWriteable := shared.AuthTokenWriteable(cfg, hostname)
+		_, tokenIsWriteable := shared.AuthTokenWriteable(authCfg, hostname)
 
 		statusInfo[hostname] = []string{}
 		addMsg := func(x string, ys ...interface{}) {
@@ -107,7 +108,7 @@ func statusRun(opts *StatusOptions) error {
 		scopesHeader, err := shared.GetScopes(httpClient, hostname, token)
 		if err != nil {
 			addMsg("%s %s: authentication failed", cs.Red("X"), hostname)
-			addMsg("- The %s token in %s is no longer valid.", cs.Bold(hostname), tokenSource)
+			addMsg("- The %s token in %s is invalid.", cs.Bold(hostname), tokenSource)
 			if tokenIsWriteable {
 				addMsg("- To re-authenticate, run: %s %s",
 					cs.Bold("gh auth login -h"), cs.Bold(hostname))
@@ -138,7 +139,7 @@ func statusRun(opts *StatusOptions) error {
 			}
 
 			addMsg("%s Logged in to %s as %s (%s)", cs.SuccessIcon(), hostname, cs.Bold(username), tokenSource)
-			proto, _ := cfg.GetOrDefault(hostname, "git_protocol")
+			proto, _ := authCfg.GitProtocol(hostname)
 			if proto != "" {
 				addMsg("%s Git operations for %s configured to use %s protocol.",
 					cs.SuccessIcon(), hostname, cs.Bold(proto))
@@ -165,13 +166,22 @@ func statusRun(opts *StatusOptions) error {
 		if !ok {
 			continue
 		}
-		if prevEntry {
+		if prevEntry && failed {
 			fmt.Fprint(stderr, "\n")
+		} else if prevEntry && !failed {
+			fmt.Fprint(stdout, "\n")
 		}
 		prevEntry = true
-		fmt.Fprintf(stderr, "%s\n", cs.Bold(hostname))
-		for _, line := range lines {
-			fmt.Fprintf(stderr, "  %s\n", line)
+		if failed {
+			fmt.Fprintf(stderr, "%s\n", cs.Bold(hostname))
+			for _, line := range lines {
+				fmt.Fprintf(stderr, "  %s\n", line)
+			}
+		} else {
+			fmt.Fprintf(stdout, "%s\n", cs.Bold(hostname))
+			for _, line := range lines {
+				fmt.Fprintf(stdout, "  %s\n", line)
+			}
 		}
 	}
 
