@@ -10,6 +10,7 @@ import (
 	"log"
 	"os"
 	"sort"
+	"strings"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/AlecAivazis/survey/v2/terminal"
@@ -59,6 +60,10 @@ func (a *App) StopProgressIndicator() {
 	a.io.StopProgressIndicator()
 }
 
+func (a *App) RunWithProgress(label string, run func() error) error {
+	return a.io.RunWithProgress(label, run)
+}
+
 // Connects to a codespace using Live Share and returns that session
 func startLiveShareSession(ctx context.Context, codespace *api.Codespace, a *App, debug bool, debugFile string) (session *liveshare.Session, err error) {
 	liveshareLogger := noopLogger()
@@ -83,6 +88,7 @@ func startLiveShareSession(ctx context.Context, codespace *api.Codespace, a *App
 
 //go:generate moq -fmt goimports -rm -skip-ensure -out mock_api.go . apiClient
 type apiClient interface {
+	ServerURL() string
 	GetUser(ctx context.Context) (*api.User, error)
 	GetCodespace(ctx context.Context, name string, includeConnection bool) (*api.Codespace, error)
 	GetOrgMemberCodespace(ctx context.Context, orgName string, userName string, codespaceName string) (*api.Codespace, error)
@@ -102,21 +108,17 @@ type apiClient interface {
 
 var errNoCodespaces = errors.New("you have no codespaces")
 
-func chooseCodespace(ctx context.Context, apiClient apiClient) (*api.Codespace, error) {
-	codespaces, err := apiClient.ListCodespaces(ctx, api.ListCodespacesOptions{})
-	if err != nil {
-		return nil, fmt.Errorf("error getting codespaces: %w", err)
-	}
-	return chooseCodespaceFromList(ctx, codespaces, false)
-}
-
 // chooseCodespaceFromList returns the codespace that the user has interactively selected from the list, or
 // an error if there are no codespaces.
-func chooseCodespaceFromList(ctx context.Context, codespaces []*api.Codespace, includeOwner bool) (*api.Codespace, error) {
+func chooseCodespaceFromList(ctx context.Context, codespaces []*api.Codespace, includeOwner bool, skipPromptForSingleOption bool) (*api.Codespace, error) {
 	if len(codespaces) == 0 {
 		return nil, errNoCodespaces
 	}
 
+	if skipPromptForSingleOption && len(codespaces) == 1 {
+		return codespaces[0], nil
+	}
+
 	sortedCodespaces := codespaces
 	sort.Slice(sortedCodespaces, func(i, j int) bool {
 		return sortedCodespaces[i].CreatedAt > sortedCodespaces[j].CreatedAt
@@ -154,35 +156,6 @@ func formatCodespacesForSelect(codespaces []*api.Codespace, includeOwner bool) [
 	return names
 }
 
-// getOrChooseCodespace prompts the user to choose a codespace if the codespaceName is empty.
-// It then fetches the codespace record with full connection details.
-// TODO(josebalius): accept a progress indicator or *App and show progress when fetching.
-func getOrChooseCodespace(ctx context.Context, apiClient apiClient, codespaceName string) (codespace *api.Codespace, err error) {
-	if codespaceName == "" {
-		codespace, err = chooseCodespace(ctx, apiClient)
-		if err != nil {
-			if err == errNoCodespaces {
-				return nil, err
-			}
-			return nil, fmt.Errorf("choosing codespace: %w", err)
-		}
-	} else {
-		codespace, err = apiClient.GetCodespace(ctx, codespaceName, true)
-		if err != nil {
-			return nil, fmt.Errorf("getting full codespace details: %w", err)
-		}
-	}
-
-	if codespace.PendingOperation {
-		return nil, fmt.Errorf(
-			"codespace is disabled while it has a pending operation: %s",
-			codespace.PendingOperationDisabledReason,
-		)
-	}
-
-	return codespace, nil
-}
-
 func safeClose(closer io.Closer, err *error) {
 	if closeErr := closer.Close(); *err == nil {
 		*err = closeErr
@@ -289,5 +262,20 @@ func addDeprecatedRepoShorthand(cmd *cobra.Command, target *string) error {
 		return fmt.Errorf("error marking `-r` shorthand as deprecated: %w", err)
 	}
 
+	if cmd.Flag("codespace") != nil {
+		cmd.MarkFlagsMutuallyExclusive("codespace", "repo-deprecated")
+	}
+
 	return nil
 }
+
+// filterCodespacesByRepoOwner filters a list of codespaces by the owner of the repository.
+func filterCodespacesByRepoOwner(codespaces []*api.Codespace, repoOwner string) []*api.Codespace {
+	filtered := make([]*api.Codespace, 0, len(codespaces))
+	for _, c := range codespaces {
+		if strings.EqualFold(c.Repository.Owner.Login, repoOwner) {
+			filtered = append(filtered, c)
+		}
+	}
+	return filtered
+}
