@@ -18,6 +18,7 @@ type listOptions struct {
 	repo     string
 	orgName  string
 	userName string
+	useWeb   bool
 }
 
 func newListCmd(app *App) *cobra.Command {
@@ -34,11 +35,29 @@ func newListCmd(app *App) *cobra.Command {
 		`),
 		Aliases: []string{"ls"},
 		Args:    noArgsConstraint,
-		RunE: func(cmd *cobra.Command, args []string) error {
+		PreRunE: func(cmd *cobra.Command, args []string) error {
+			if err := cmdutil.MutuallyExclusive(
+				"using `--org` or `--user` with `--repo` is not allowed",
+				opts.repo != "",
+				opts.orgName != "" || opts.userName != "",
+			); err != nil {
+				return err
+			}
+
+			if err := cmdutil.MutuallyExclusive(
+				"using `--web` with `--org` or `--user` is not supported, please use with `--repo` instead",
+				opts.useWeb,
+				opts.orgName != "" || opts.userName != "",
+			); err != nil {
+				return err
+			}
+
 			if opts.limit < 1 {
 				return cmdutil.FlagErrorf("invalid limit: %v", opts.limit)
 			}
-
+			return nil
+		},
+		RunE: func(cmd *cobra.Command, args []string) error {
 			return app.List(cmd.Context(), opts, exporter)
 		},
 	}
@@ -51,20 +70,23 @@ func newListCmd(app *App) *cobra.Command {
 
 	listCmd.Flags().StringVarP(&opts.orgName, "org", "o", "", "The `login` handle of the organization to list codespaces for (admin-only)")
 	listCmd.Flags().StringVarP(&opts.userName, "user", "u", "", "The `username` to list codespaces for (used with --org)")
-	cmdutil.AddJSONFlags(listCmd, &exporter, api.CodespaceFields)
+	cmdutil.AddJSONFlags(listCmd, &exporter, api.ListCodespaceFields)
+
+	listCmd.Flags().BoolVarP(&opts.useWeb, "web", "w", false, "List codespaces in the web browser, cannot be used with --user or --org")
 
 	return listCmd
 }
 
 func (a *App) List(ctx context.Context, opts *listOptions, exporter cmdutil.Exporter) error {
-	// if repo is provided, we don't accept orgName or userName
-	if opts.repo != "" && (opts.orgName != "" || opts.userName != "") {
-		return cmdutil.FlagErrorf("using `--org` or `--user` with `--repo` is not allowed")
+	if opts.useWeb && opts.repo == "" {
+		return a.browser.Browse(fmt.Sprintf("%s/codespaces", a.apiClient.ServerURL()))
 	}
 
-	a.StartProgressIndicatorWithLabel("Fetching codespaces")
-	codespaces, err := a.apiClient.ListCodespaces(ctx, api.ListCodespacesOptions{Limit: opts.limit, RepoName: opts.repo, OrgName: opts.orgName, UserName: opts.userName})
-	a.StopProgressIndicator()
+	var codespaces []*api.Codespace
+	err := a.RunWithProgress("Fetching codespaces", func() (err error) {
+		codespaces, err = a.apiClient.ListCodespaces(ctx, api.ListCodespacesOptions{Limit: opts.limit, RepoName: opts.repo, OrgName: opts.orgName, UserName: opts.userName})
+		return
+	})
 	if err != nil {
 		return fmt.Errorf("error getting codespaces: %w", err)
 	}
@@ -90,6 +112,10 @@ func (a *App) List(ctx context.Context, opts *listOptions, exporter cmdutil.Expo
 		return cmdutil.NewNoResultsError("no codespaces found")
 	}
 
+	if opts.useWeb && codespaces[0].Repository.ID > 0 {
+		return a.browser.Browse(fmt.Sprintf("%s/codespaces?repository_id=%d", a.apiClient.ServerURL(), codespaces[0].Repository.ID))
+	}
+
 	//nolint:staticcheck // SA1019: utils.NewTablePrinter is deprecated: use internal/tableprinter
 	tp := utils.NewTablePrinter(a.io)
 	if tp.IsTTY() {
