@@ -20,7 +20,7 @@ import (
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/set"
 	"github.com/cli/cli/v2/utils"
-	ghAPI "github.com/cli/go-gh/pkg/api"
+	ghAPI "github.com/cli/go-gh/v2/pkg/api"
 	"github.com/spf13/cobra"
 	"golang.org/x/sync/errgroup"
 )
@@ -68,7 +68,7 @@ func NewCmdStatus(f *cmdutil.Factory, runF func(*StatusOptions) error) *cobra.Co
 				return err
 			}
 
-			opts.HostConfig = cfg
+			opts.HostConfig = cfg.Authentication()
 
 			if runF != nil {
 				return runF(opts)
@@ -286,7 +286,28 @@ func (s *StatusGetter) LoadNotifications() error {
 					if !ok {
 						return nil
 					}
-					if actual, err := s.ActualMention(n.Subject.LatestCommentURL); actual != "" && err == nil {
+					actual, err := s.ActualMention(n.Subject.LatestCommentURL)
+
+					if err != nil {
+						var httpErr api.HTTPError
+						httpStatusCode := -1
+
+						if errors.As(err, &httpErr) {
+							httpStatusCode = httpErr.StatusCode
+						}
+
+						switch httpStatusCode {
+						case 403:
+							s.addAuthError(httpErr.Message, factory.SSOURL())
+						case 404:
+							return nil
+						default:
+							abortFetching()
+							return fmt.Errorf("could not fetch comment: %w", err)
+						}
+					}
+
+					if actual != "" {
 						// I'm so sorry
 						split := strings.Split(n.Subject.URL, "/")
 						fetched <- StatusItem{
@@ -295,14 +316,6 @@ func (s *StatusGetter) LoadNotifications() error {
 							preview:    actual,
 							index:      n.index,
 						}
-					} else if err != nil {
-						var httpErr api.HTTPError
-						if errors.As(err, &httpErr) && httpErr.StatusCode == 403 {
-							s.addAuthError(httpErr.Message, factory.SSOURL())
-						} else {
-							abortFetching()
-							return fmt.Errorf("could not fetch comment: %w", err)
-						}
 					}
 				}
 			}
@@ -429,7 +442,7 @@ func (s *StatusGetter) LoadSearchResults() error {
 	if err != nil {
 		var gqlErrResponse api.GraphQLError
 		if errors.As(err, &gqlErrResponse) {
-			gqlErrors := make([]ghAPI.GQLErrorItem, 0, len(gqlErrResponse.Errors))
+			gqlErrors := make([]ghAPI.GraphQLErrorItem, 0, len(gqlErrResponse.Errors))
 			// Exclude any FORBIDDEN errors and show status for what we can.
 			for _, gqlErr := range gqlErrResponse.Errors {
 				if gqlErr.Type == "FORBIDDEN" {
@@ -442,7 +455,7 @@ func (s *StatusGetter) LoadSearchResults() error {
 				err = nil
 			} else {
 				err = api.GraphQLError{
-					GQLError: ghAPI.GQLError{
+					GraphQLError: &ghAPI.GraphQLError{
 						Errors: gqlErrors,
 					},
 				}
@@ -467,7 +480,7 @@ func (s *StatusGetter) LoadSearchResults() error {
 		case "PullRequest":
 			prs = append(prs, *node)
 		default:
-			return fmt.Errorf("unkown Assignments type: %q", node.Type)
+			return fmt.Errorf("unknown Assignments type: %q", node.Type)
 		}
 	}
 
